use chrono::{NaiveDate, NaiveDateTime, NaiveTime};
use dotenv::dotenv;
use std::env;
use terminwahl_back::db;

#[actix_web::main]
async fn main() -> std::io::Result<()> {
    dotenv().ok();
    env_logger::init_from_env(env_logger::Env::new().default_filter_or("info"));

    let database_url = env::var("DATABASE_URL").expect("DATABASE_URL must be set");
    let pool = db::init_pool(&database_url)
        .await
        .expect("Failed to create pool");
    let duration = chrono::Duration::minutes(15);
    let date = NaiveDate::from_ymd_opt(2023, 2, 28).unwrap();
    let time = NaiveTime::from_hms_opt(14, 30, 0).unwrap();
    let mut start = NaiveDateTime::new(date, time);
    for _ in 0..4 {
        let end = start + duration;
        sqlx::query("INSERT INTO appointment_slots (start_time, end_time) VALUES (?, ?)")
            .bind(start)
            .bind(end)
            .execute(&pool)
            .await
            .unwrap();
        start = end;
    }
    start += duration;
    for _ in 0..4 {
        let end = start + duration;
        sqlx::query("INSERT INTO appointment_slots (start_time, end_time) VALUES (?, ?)")
            .bind(start)
            .bind(end)
            .execute(&pool)
            .await
            .unwrap();
        start = end;
    }
    Ok(())
}
